@@ -16,8 +16,8 @@ fn main()
 		PlotData {
 			axis_x: vec![0.0, 1.0],
 			axis_y: vec![-1.0, 1.0],
-			values_x: vec![0.0, 0.5],//, 300.0, 400.0],
-			values_y: vec![0.0, 0.5]//, 400.0, 400.0]
+			values_x: vec![0.0, 0.1, 0.2, 0.3, 0.4, 0.5],//, 300.0, 400.0],
+			values_y: vec![0.0, -0.1, 0.5, -0.2, 0.0, 0.5]//, 400.0, 400.0]
 		}
 	});
 }
\ No newline at end of file
